/********************************
  netpuyo(client)
  resource.c --- fallback resources
  (C) Oct 6, 1997 ROYALPANDA
*******************************/

#include<stdio.h>

unsigned char *DefaultResources[] = {

"Netpuyo*font			: -*-courier-*-r-*-*-24-*-*-*-*-*-*-*",
"Netpuyo*foreground		: white",
"Netpuyo*background		: black",
"Netpuyo*borderColor            : grey",
"Netpuyo*defaultDistance	: 16",
"Netpuyo*borderWidth              : 2",
"Netpuyo*Label.justify            : center",
"Netpuyo*Label.borderWidth        : 0",
"Netpuyo*Core.borderWidth         : 0",
"Netpuyo*Form.borderWidth         : 0",

"Netpuyo*puyo.vertDistance:0",
"Netpuyo*puyo.horizDistance:0",

"Netpuyo*wait.label : Waiting for\\nanother connection...",
"Netpuyo*wait.horizDistance  : 64",
"Netpuyo*wait.vertDistance  : 200",

"Netpuyo*win0.vertDistance: 200",
"Netpuyo*win0.label:Won!",
"Netpuyo*lose0.vertDistance: 200",
"Netpuyo*lose0.label:Lost!",

"Netpuyo*stock0.vertDistance : 0",
"Netpuyo*scr0.vertDistance : 32",

"Netpuyo*msg0.fromVert   : scr0",

"Netpuyo*next0.fromHoriz : scr0",
"Netpuyo*next0.vertDistance:128",
"Netpuyo*next0.borderWidth:8",

"Netpuyo*next1.fromHoriz : next0",
"Netpuyo*next1.vertDistance : 128",
"Netpuyo*next1.borderWidth:8",

"Netpuyo*win1.fromHoriz:next1",
"Netpuyo*win1.vertDistance: 200",
"Netpuyo*win1.label:Won!",
"Netpuyo*lose1.fromHoriz:next1",
"Netpuyo*lose1.vertDistance: 200",
"Netpuyo*lose1.label:Lost!",
"Netpuyo*stock1.fromHoriz:next1",
"Netpuyo*stock1.vertDistance: 0",
"Netpuyo*scr1.fromHoriz : next1",
"Netpuyo*scr1.vertDistance: 32",

"Netpuyo*msg1.fromHoriz  : next1",
"Netpuyo*msg1.fromVert   : scr1",

"Netpuyo*copyright.font	: -*-courier-*-*-*-*-20-*-*-*-*-*-*-*",
"Netpuyo*copyright.foreground : green",
"Netpuyo*copyright.label : NetPuyo  version 1.0  (C) 1997 ROYALPANDA\\n\
Please send bug report to : i11053@ced.cas.uec.ac.jp",

"Netpuyo*copyright.fromVert : msg1",

"Netpuyo*chat.value.width : 512",
"Netpuyo*chat.label.width : 600",
"Netpuyo*chat.label.justify : left",
"Netpuyo*chat*font        : -*-*-*-*-*-*-20-*-*-*-c-*-*-*",
"Netpuyo*bell.label       : BELL",

"Netpuyo*puyo.translations	: #override \\n\
<Key>space    : key_on(FALL)start() \\n\
<KeyUp>space  : key_off(FALL) \\n\
<Key>k        : key_on(FALL)  \\n\
<KeyUp>k      : key_off(FALL) \\n\
<Key>Down     : key_on(FALL)  \\n\
<KeyUp>Down   : key_off(FALL) \\n\
<Key>Shift_L  : key_on(FALL)  \\n\
<KeyUp>Shift_L: key_off(FALL) \\n\
<Key>Shift_R  : key_on(FALL)  \\n\
<KeyUp>Shift_R: key_off(FALL) \\n\
\
<Key>l       : key_on(RIGHT) \\n\
<KeyUp>l     : key_off(RIGHT)\\n\
<Key>Right   : key_on(RIGHT) \\n\
<KeyUp>Right : key_off(RIGHT)\\n\
\
<Key>j       : key_on(LEFT)  \\n\
<KeyUp>j     : key_off(LEFT) \\n\
<Key>Left    : key_on(LEFT)  \\n\
<KeyUp>Left  : key_off(LEFT) \\n\
\
<Key>i       : key_on(+)     \\n\
<KeyUp>i     : key_off(+)    \\n\
<Key>Up      : key_on(+)     \\n\
<KeyUp>Up    : key_off(+)    \\n\
<Key>c       : key_on(+)     \\n\
<KeyUp>c     : key_off(+)    \\n\
\
<Key>x       : key_on(-)     \\n\
<KeyUp>x     : key_off(-)    \\n\
\
<Key>Tab     : point(CHAT) \\n\
:<Key>Q      : quit()
",
"Netpuyo*chat*translations : #override \\n\
<Key>Return  : send_msg() \\n\
<Key>Tab     : point(GAME) \\n\
Ctrl<Key>j   : send_msg()
",

NULL };
